%bcond_without check

# https://github.com/linuxdeepin/dde-daemon
%global goipath         github.com/linuxdeepin/dde-daemon
Version:                6.0.37
%global tag             %{version}

%gometa -L -f

%global repo dde-daemon

Name:           deepin-daemon
Release:        %autorelease
Summary:        Daemon handling the DDE session settings
License:        GPL-3.0-or-later
URL:            %{gourl}
Source:         %{gosource}

# upstream default mono font set to 'Noto Mono', which is not yet available in
# Fedora. We change to 'Noto Sans Mono'
Source1:        fontconfig.json
Source2:        deepin-daemon.sysusers

Patch0:         https://gitlab.archlinux.org/archlinux/packaging/packages/deepin-daemon/-/raw/main/deepin-daemon-fix-vanilla-libinput.patch
Patch1:         https://gitlab.archlinux.org/archlinux/packaging/packages/deepin-daemon/-/raw/main/ddcutil-2.patch
Patch2:         0001-fix-install-makefile.patch

# accord with ddcutil
ExcludeArch:    s390x

BuildRequires:  python3
BuildRequires:  deepin-gettext-tools
BuildRequires:  fontpackages-devel
BuildRequires:  librsvg2-tools
BuildRequires:  pam-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk3-devel
BuildRequires:  systemd-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  alsa-lib-devel
BuildRequires:  pulseaudio-libs-devel
BuildRequires:  gdk-pixbuf2-xlib-devel
BuildRequires:  libnl3-devel
BuildRequires:  libgudev-devel
BuildRequires:  libinput-devel
BuildRequires:  librsvg2-devel
BuildRequires:  libXcursor-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  python3-gobject
BuildRequires:  NetworkManager-libnm-devel
BuildRequires:  pkgconfig(ddcutil)
# for test
BuildRequires:  deepin-desktop-base
BuildRequires:  deepin-desktop-schemas
BuildRequires:  gcc-c++

Requires:       bamf-daemon
Requires:       bluez-obexd
Requires:       gnome-keyring
Requires:       deepin-desktop-base
Requires:       deepin-desktop-schemas
Requires:       deepin-session-ui
Requires:       deepin-polkit-agent
Requires:       rfkill
Requires:       gvfs
Requires:       iw
Requires:       lightdm
Requires:       xsettingsd

Recommends:     lshw
Recommends:     iso-codes
Recommends:     imwheel
Recommends:     %{_bindir}/xmodmap
Recommends:     mobile-broadband-provider-info
Recommends:     google-noto-mono-fonts
Recommends:     google-noto-sans-fonts
Recommends:     google-noto-sans-mono-fonts

%description
Daemon handling the DDE session settings

%gopkg

%prep
%goprep -A
%autopatch -p1

%generate_buildrequires
%go_generate_buildrequires

sed -i 's|${DESTDIR}/lib/udev/rules.d|${DESTDIR}$(PREFIX)/lib/udev/rules.d|' Makefile
sed -i 's|${DESTDIR}/lib/systemd/|${DESTDIR}$(PREFIX)/lib/systemd/|' Makefile
sed -i 's|${DESTDIR}${PREFIX}/lib/deepin-daemon/service-trigger|${DESTDIR}%{_libdir}/deepin-daemon/service-trigger|' \
    Makefile
sed -i 's|lib/NetworkManager|libexec|' network/utils_test.go
sed -i 's|/etc/os-version|/etc/uos-version|' keybinding/shortcuts/shortcut_manager.go

sed -i "s|/usr/share/dde/zoneinfo/zone1970.tab|$(pwd)/misc/zoneinfo/zone1970.tab|" timedate1/zoneinfo/zone.go

for file in $(grep "/usr/lib/deepin-daemon" * -nR |awk -F: '{print $1}')
do
    sed -i 's|/usr/lib/deepin-daemon|%{_libexecdir}/deepin-daemon|g' $file
done
for file in $(grep "/usr/lib/deepin-api" * -nR |awk -F: '{print $1}')
do
    sed -i 's|/usr/lib/deepin-api|%{_libexecdir}/deepin-api|g' $file
done

# Fix grub.cfg path
sed -i 's|boot/grub|boot/grub2|' grub2/{grub2,grub_params,theme}.go

# systemd service
cat > misc/systemd/services/dbus-com.deepin.dde.lockservice.service <<EOF
[Unit]
Description=Deepin Lock Service
Wants=user.slice dbus.socket
After=user.slice dbus.socket

[Service]
Type=dbus
BusName=com.deepin.dde.LockService
ExecStart=%{_libexecdir}/%{sname}/dde-lockservice

[Install]
WantedBy=graphical.target
EOF

# Replace reference of google-chrome to chromium-browser
sed -i 's/google-chrome/chromium-browser/g' misc/dde-daemon/mime/data.json

%build
export GOPATH="$(pwd)/gopath:%{gopath}"
export %{gomodulesmode}
%make_build -C network/nm_generator gen-nm-code
# build different golang binaries with different build-id
make prepare
for cmd in bin/* ; do
  if ! [ -f $cmd/main.c ]; then
    %gobuild -o out/bin/$(basename $cmd) github.com/linuxdeepin/dde-daemon/$cmd
  fi
done
BUILDID="0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \n')"
%make_build GO_BUILD_FLAGS=-trimpath GOBUILD="go build -compiler gc -ldflags \"-B $BUILDID\""

%install
BUILDID="0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \n')"
export GOPATH="$(pwd)/build:%{gopath}"
export %{gomodulesmode}
%make_install GOBUILD="go build -compiler gc -ldflags \"-B $BUILDID\""

install -Dm644 %{SOURCE2} %{buildroot}/usr/lib/sysusers.d/%{name}.conf

# fix systemd/logind config
install -d %{buildroot}/usr/lib/systemd/logind.conf.d/
cat > %{buildroot}/usr/lib/systemd/logind.conf.d/10-%{sname}.conf <<EOF
[Login]
HandlePowerKey=ignore
HandleSuspendKey=ignore
EOF

# install default settings
install -Dm644 %{SOURCE1} \
    %{buildroot}%{_datadir}/deepin-default-settings/fontconfig.json

%find_lang %{repo}

%if %{with check}
%check
%gocheck -d session/eventlog -d accounts1 -d accounts1/users
%endif

%post
if [ $1 -ge 1 ]; then
  systemd-sysusers %{sname}.conf
  %{_sbindir}/alternatives --install %{_bindir}/x-terminal-emulator \
    x-terminal-emulator %{_libexecdir}/%{sname}/default-terminal 30
fi

%preun
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove x-terminal-emulator \
    %{_libexecdir}/%{sname}/default-terminal
fi

%postun
if [ $1 -eq 0 ]; then
  rm -f /var/cache/deepin/mark-setup-network-services
  rm -f /var/log/deepin.log
fi

%files -f %{repo}.lang
%doc README.md
%license LICENSE
%{_sysconfdir}/pam.d/deepin-auth-keyboard
%{_sysconfdir}/NetworkManager/conf.d/deepin.dde.daemon.conf
%{_libexecdir}/%{repo}/
%{_prefix}/lib/systemd/logind.conf.d/10-%{sname}.conf
%{_datadir}/dbus-1/services/*.service
%{_datadir}/dbus-1/system-services/*.service
%{_datadir}/dbus-1/system.d/*.conf
%{_datadir}/icons/hicolor/*/status/*
%{_datadir}/%{repo}/
%{_datadir}/dde/
%{_datadir}/polkit-1/actions/*.policy
%{_sysconfdir}/acpi/actions/deepin_lid.sh
%{_sysconfdir}/acpi/events/deepin_lid
%{_userunitdir}/dde-session-initialized.target.wants/org.dde.session.Daemon1.service
%{_unitdir}/deepin-accounts1-daemon.service
%{_userunitdir}/*.service
%{_datadir}/deepin/scheduler/config.json
%{_libexecdir}/deepin-daemon/
%{_libdir}/deepin-daemon/service-trigger/ACL.service.json
%{_var}/lib/polkit-1/localauthority/10-vendor.d/*.pkla
%{_udevrulesdir}/80-deepin-fprintd.rules
# This directory is not provided by any other package.
%dir %{_sysconfdir}/pulse/daemon.conf.d
%{_sysconfdir}/pulse/daemon.conf.d/10-deepin.conf
%{_sysusersdir}/%{name}.conf
%{_datadir}/deepin-default-settings/
%exclude %{_sysconfdir}/deepin/grub2_edit_auth.conf
%exclude %{_sysconfdir}/default/grub.d/10_deepin.cfg
%{_datadir}/dsg/

%changelog
%autochangelog
